module.exports = defineTest({
	description: 'only evaluate the second part of a logical expression if necessary'
});
